@@ -1,12 +1,12 @@
 var indexSectionsWithContent =
 {
   0: "_abcdefghijklmnopqrstuvwxyz~",
-  1: "bchimrtw",
+  1: "bcghimrtw",
   2: "abcdefghijklmnopqrstuvwxz",
-  3: "_abcdefghiklmnopqrstuvwxyz~",
+  3: "_abcdefghijklmnopqrstuvwxyz~",
   4: "abcdefghiklmnoprstvwxy",
   5: "bcdefiprsvw",
-  6: "abcdehkmnorstvwy",
+  6: "abcdefhkmnoprstvwy",
   7: "abcdefghijklmnopqrstuw",
   8: "w",
   9: "_w",
